@@ -1,4 +1,4 @@
-/* Copyright (C) 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -26,18 +26,13 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/wait.h>
 
+#include "i18n.h"
 #include "public.h"
 #include "logging.h"
 #include "logindefs.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 /* call_script reads the command to be called for "variable"
    from /etc/login.defs. */
 int
