@@ -1,4 +1,4 @@
-/* Copyright (C) 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -23,16 +23,12 @@
 #include <utmp.h>
 #include <stdio.h>
 #include <string.h>
-#include <libintl.h>
 #include <regex.h>
 
+#include "i18n.h"
 #include "public.h"
 #include "logindefs.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 /* Return 0 if name is POSIX conform, -1 else.  */
 int
 check_name (const char *name)
