@@ -1,4 +1,4 @@
-/* Copyright (C) 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -24,8 +24,6 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include <locale.h>
-#include <libintl.h>
 
 #if defined HAVE_SYS_XATTR_H
 #include <sys/xattr.h>
@@ -36,12 +34,9 @@
 #include <selinux/selinux.h>
 #endif
 
+#include "i18n.h"
 #include "public.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 int
 copy_xattr (const char *from, const char *to)
 {
