@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Thorsten Kukuk
+/* Copyright (C) 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -24,14 +24,10 @@
 
 #include <unistd.h>
 #include <string.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "libldap.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 char *
 get_caller_dn (void)
 {
