@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Thorsten Kukuk
+/* Copyright (C) 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -21,14 +21,10 @@
 #ifdef USE_LDAP
 
 #include <unistd.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "libldap.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 char *
 get_ldap_password (const char *binddn)
 {
