@@ -25,8 +25,6 @@
 #include <dlfcn.h>
 #include <errno.h>
 #include <unistd.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/stat.h>
 #include <rpcsvc/yp_prot.h>
 #include <rpcsvc/ypclnt.h>
@@ -39,14 +37,11 @@
 #endif
 
 #include "nsw.h"
-#include "yppasswd.h"
+#include "i18n.h"
 #include "group.h"
+#include "yppasswd.h"
 #include "read-files.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 void
 free_group_t (group_t *data)
 {
