@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -22,13 +22,8 @@
 
 #include <utmp.h>
 #include <string.h>
-#include <locale.h>
-#include <libintl.h>
-
-#ifndef _
-#define _(String) gettext (String)
-#endif
 
+#include "i18n.h"
 #include "public.h"
 
 /* Check if the user is logged in.
