@@ -1,4 +1,4 @@
-/* Copyright (C) 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2003, 2004, 2005 Thorsten Kukuk
    The basis of this code is from the pam_ldap-148 package written
    by Luke Howard.
 
@@ -35,8 +35,6 @@
 #include <syslog.h>
 #include <netdb.h>
 #include <errno.h>
-#include <locale.h>
-#include <libintl.h>
 
 #ifdef HAVE_LBER_H
 #include <lber.h>
@@ -48,13 +46,11 @@
 #include <ldap_ssl.h>
 #endif
 
+#include "i18n.h"
+
 #define _INCLUDED_FROM_LIBLDAP_C_
 #include "libldap.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #ifndef HAVE_LDAP_MEMFREE
 #define ldap_memfree(x)	free(x)
 #endif
