@@ -1,4 +1,4 @@
-/* Copyright (C) 2002, 2003 Thorsten Kukuk
+/* Copyright (C) 2002, 2003, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -23,14 +23,10 @@
 
 #include <errno.h>
 #include <unistd.h>
-#include <locale.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "public.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
 
 #define MAX_LOCK_RETRIES 3 /* How often should we try to lock password file */
 
@@ -50,4 +46,3 @@ lock_database (void)
 
   return 0;
 }
-
