@@ -28,15 +28,10 @@
 #include <syslog.h>
 #include <stdarg.h>
 #include <stdlib.h>
-#include <locale.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "logging.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 struct logfunc_t *logfunc_list = NULL;
 
 /* Add a new entry to the list.  */
