@@ -25,20 +25,15 @@
 #include <time.h>
 #include <unistd.h>
 #include <string.h>
-#include <locale.h>
-#include <libintl.h>
 #if defined(HAVE_XCRYPT_H)
 #include <xcrypt.h>
 #elif defined(HAVE_CRYPT_H)
 #include <crypt.h>
 #endif
 
+#include "i18n.h"
 #include "parse_crypt_arg.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #ifndef RANDOM_DEVICE
 #define RANDOM_DEVICE "/dev/urandom"
 #endif
