@@ -24,8 +24,6 @@
 #include <pwd.h>
 #include <time.h>
 #include <ctype.h>
-#include <locale.h>
-#include <libintl.h>
 #include <unistd.h>
 #include <string.h>
 #include <rpc/key_prot.h>
@@ -35,12 +33,9 @@
 #include <security/_pam_macros.h>
 #include <security/pam_modules.h>
 
-#include "nispasswd.h"
+#include "i18n.h"
 #include "public.h"
-
-#ifndef _
-#define _(String) gettext (String)
-#endif
+#include "nispasswd.h"
 
 /* This is in glibc, but not in the headers */
 extern int key_get_conv (char *pkey, des_block *deskey);
