@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -19,15 +19,10 @@
 #endif
 
 #include <stdio.h>
-#include <locale.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "public.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 void
 print_error (const char *program)
 {
@@ -35,4 +30,3 @@ print_error (const char *program)
            _("Try `%s --help' or `%s --usage' for more information.\n"),
            program, program);
 }
-
