@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Thorsten Kukuk
+/* Copyright (C) 2003, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -19,9 +19,8 @@
 #endif
 
 #include <stdio.h>
-#include <locale.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "public.h"
 
 /* Print the version information.  */
@@ -29,11 +28,10 @@ void
 print_version (const char *program, const char *years)
 {
   fprintf (stdout, "%s (%s) %s\n", program, PACKAGE, VERSION);
-  fprintf (stdout, gettext ("\
+  fprintf (stdout, _("\
 Copyright (C) %s Thorsten Kukuk.\n\
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 "), years);
   /* fprintf (stdout, _("Written by %s.\n"), "Thorsten Kukuk"); */
 }
-
