@@ -26,19 +26,14 @@
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/types.h>
 #include <selinux/flask.h>
 #include <selinux/selinux.h>
 #include <selinux/context.h>
 
+#include "i18n.h"
 #include "public.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 int
 selinux_check_access (const char *chuser, unsigned int selaccess)
 {
