@@ -31,14 +31,13 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <shadow.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
 #ifdef HAVE_LIBNSCD_H
 #include <libnscd.h>
 #endif
 
+#include "i18n.h"
 #include "error_codes.h"
 #include "public.h"
 #include "logindefs.h"
@@ -50,10 +49,6 @@
 #include "libldap.h"
 #endif
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #define DAY (24L*3600L)
 #define SCALE DAY
 
@@ -126,19 +121,19 @@ print_shadow_info (user_t *data)
     print_date (data->sp.sp_lstchg * SCALE);
   printf (_("Password Expires:\t"));
   if (data->sp.sp_lstchg <= 0 || data->sp.sp_max >= 10000 * (DAY / SCALE)
-      || data->sp.sp_max <= 0)
+      || data->sp.sp_max < 0)
     printf (_("Never\n"));
   else
     print_date (data->sp.sp_lstchg * SCALE + data->sp.sp_max * SCALE);
   printf (_("Password Inactive:\t"));
-  if (data->sp.sp_lstchg <= 0 || data->sp.sp_inact <= 0 ||
-      data->sp.sp_max >= 10000 * (DAY / SCALE) || data->sp.sp_max <= 0)
+  if (data->sp.sp_lstchg <= 0 || data->sp.sp_inact < 0 ||
+      data->sp.sp_max >= 10000 * (DAY / SCALE) || data->sp.sp_max < 0)
     printf (_("Never\n"));
   else
     print_date (data->sp.sp_lstchg * SCALE +
 		(data->sp.sp_max + data->sp.sp_inact) * SCALE);
   printf (_("Account Expires:\t"));
-  if (data->sp.sp_expire <= 0)
+  if (data->sp.sp_expire < 0)
     printf (_("Never\n"));
   else
     print_date (data->sp.sp_expire * SCALE);
