@@ -33,8 +33,6 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <shadow.h>
-#include <locale.h>
-#include <libintl.h>
 #ifdef WITH_SELINUX
 #include <selinux/selinux.h>
 #include <selinux/av_permissions.h>
@@ -43,6 +41,7 @@
 #include <libnscd.h>
 #endif
 
+#include "i18n.h"
 #include "public.h"
 #include "utf8conv.h"
 #include "logindefs.h"
