@@ -28,8 +28,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <locale.h>
-#include <libintl.h>
 #if defined(HAVE_XCRYPT_H)
 #include <xcrypt.h>
 #elif defined(HAVE_CRYPT_H)
@@ -41,6 +39,7 @@
 #include <libnscd.h>
 #endif
 
+#include "i18n.h"
 #include "public.h"
 #include "logging.h"
 #include "logindefs.h"
