@@ -31,8 +31,6 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <shadow.h>
-#include <locale.h>
-#include <libintl.h>
 #ifdef WITH_SELINUX
 #include <selinux/selinux.h>
 #include <selinux/av_permissions.h>
@@ -41,6 +39,7 @@
 #include <libnscd.h>
 #endif
 
+#include "i18n.h"
 #include "public.h"
 #include "utf8conv.h"
 #include "logindefs.h"
@@ -51,10 +50,6 @@
 #include "libldap.h"
 #endif
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 static void
 print_usage (FILE *stream, const char *program)
 {
