@@ -27,18 +27,13 @@
 #include <string.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <locale.h>
-#include <libintl.h>
 
+#include "i18n.h"
 #include "public.h"
 #include "utf8conv.h"
 #include "logging.h"
 #include "error_codes.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #define SCALE DAY
 
 static void
