@@ -30,8 +30,6 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <signal.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/resource.h>
 #if defined(HAVE_XCRYPT_H)
 #include <xcrypt.h>
@@ -46,6 +44,7 @@
 #define _(String) gettext (String)
 #endif
 
+#include "i18n.h"
 #include "group.h"
 #include "logging.h"
 #include "logindefs.h"
