@@ -32,8 +32,6 @@
 #include <string.h>
 #include <signal.h>
 #include <libgen.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/resource.h>
 #ifdef HAVE_LIBNSCD_H
 #include <libnscd.h>
@@ -43,12 +41,9 @@
 #include "libldap.h"
 #endif
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
-#include "public.h"
+#include "i18n.h"
 #include "group.h"
+#include "public.h"
 #include "logging.h"
 #include "utf8conv.h"
 #include "logindefs.h"
