@@ -27,11 +27,10 @@
 #include <string.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "i18n.h"
 #include "yesno.h"
 #include "public.h"
 #include "read-files.h"
@@ -43,10 +42,6 @@
 #define E_PWDBUSY 4
 #define E_FAILURE 5
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #define SCALE DAY
 
 char *files_etc_dir = "/etc";
