@@ -29,22 +29,18 @@
 #include <unistd.h>
 #include <string.h>
 #include <getopt.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/stat.h>
 #ifdef HAVE_LIBNSCD_H
 #include <libnscd.h>
 #endif
 
+#include "i18n.h"
 #include "group.h"
 #include "public.h"
 #include "logindefs.h"
 #include "read-files.h"
 #include "error_codes.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
 
 struct sgrp {
   char *sg_namp;
