@@ -29,8 +29,6 @@
 #include <unistd.h>
 #include <signal.h>
 #include <getopt.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
@@ -40,15 +38,12 @@
 #include <crypt.h>
 #endif
 
+#include "i18n.h"
 #include "public.h"
 #include "logindefs.h"
 #include "error_codes.h"
 #include "utf8conv.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #ifndef MIN
 #define MIN(a,b) ((a)<(b)?(a):(b))
 #endif
