@@ -451,6 +451,30 @@ pam_sm_chauthtok (pam_handle_t *pamh, int flags,
   if (options->debug)
     __pam_log (LOG_DEBUG, "pam_sm_chauthtok() called");
 
+
+  retval = pam_get_item (pamh, PAM_USER, (const void **) &user_void);
+  if (retval != PAM_SUCCESS)
+    {
+      free (options);
+      return retval;
+    }
+  user = (char *) user_void;
+
+  if (user == NULL || strlen (user) == 0)
+    {
+      if (options->debug)
+	__pam_log (LOG_DEBUG, "user (%s) unknown", user ? user : "NULL");
+      /* The app is supposed to get us the username! */
+      free (options);
+      return PAM_USER_UNKNOWN;
+    }
+
+  if (flags & PAM_PRELIM_CHECK)
+    {
+      free (options);
+      return PAM_SUCCESS;
+    }
+
   if (options->host)
     {
       if (options->port)
@@ -486,60 +510,27 @@ pam_sm_chauthtok (pam_handle_t *pamh, int flags,
   if (options->port == NULL)
     options->port = "rpasswd";
 
-  retval = pam_get_item (pamh, PAM_USER, (const void **) &user_void);
-  if (retval != PAM_SUCCESS)
-    {
-      free (options);
-      return retval;
-    }
-  user = (char *) user_void;
-
-  if (user == NULL || strlen (user) == 0)
-    {
-      if (options->debug)
-	__pam_log (LOG_DEBUG, "user (%s) unknown", user ? user : "NULL");
-      /* The app is supposed to get us the username! */
-      free (options);
-      return PAM_USER_UNKNOWN;
-    }
-
-  if (flags & PAM_PRELIM_CHECK)
-    {
-#if 0
-      sock = connect_to_server (pamh, options->host,
-				options->port, PF_UNSPEC);
-
-      free (options);
-
-      if (sock < 0)
-	return PAM_TRY_AGAIN;
-
-      close (sock);
-#else
-      free (options);
-#endif
-      return PAM_SUCCESS;
-    }
-
 #ifdef USE_SLP
   if (used_slp)
     {
-      char *descr;
-
-      query_slp (&hostp, &portp, &descr);
       if (options->port != NULL && strcmp (options->port, "rpasswd") != 0)
-	PRINTF (STD_HANDLE, _("SLP: Found Server on %s, port %s"),
-		options->host, options->port);
+	{
+	  if (options->descr)
+	    PRINTF (STD_HANDLE, _("SLP: Found Server on %s, port %s (%s)\n"),
+		    options->host, options->port, options->descr);
+	  else
+	    PRINTF (STD_HANDLE, _("SLP: Found Server on %s, port %s\n"),
+		    options->host, options->port);
+	}
       else
-        PRINTF (STD_HANDLE, _("SLP: Found Server on %s"),
-		options->host);
-      if (descr)
-        {
-          PRINTF (STD_HANDLE, " (%s)\n", descr);
-          free (descr);
-        }
-      else
-        PRINTF (STD_HANDLE, "\n");
+	{
+	  if (options->descr)
+	    PRINTF (STD_HANDLE, _("SLP: Found Server on %s (%s)\n"),
+		    options->host, options->descr);
+	  else
+	    PRINTF (STD_HANDLE, _("SLP: Found Server on %s\n"),
+		    options->host);
+	}
     }
 #endif
 
