@@ -32,8 +32,6 @@
 #include <syslog.h>
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
-#include <locale.h>
-#include <libintl.h>
 #ifdef WITH_SELINUX
 #include <selinux/selinux.h>
 #include <selinux/av_permissions.h>
@@ -42,10 +40,7 @@
 #include <libnscd.h>
 #endif
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
+#include "i18n.h"
 #include "public.h"
 #include "logging.h"
 #include "logindefs.h"
