@@ -29,8 +29,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <locale.h>
-#include <libintl.h>
 #include <termios.h>
 #include <arpa/inet.h>
 #include <sys/param.h>
@@ -54,6 +52,7 @@
 #include <openssl/err.h>
 #endif
 
+#include "i18n.h"
 #include "dbg_log.h"
 #include "rpasswd-client.h"
 #include "error_codes.h"
