@@ -29,8 +29,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <locale.h>
-#include <libintl.h>
 #include <arpa/inet.h>
 #include <sys/param.h>
 #include <sys/poll.h>
@@ -56,16 +54,13 @@
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
 
+#include "i18n.h"
 #include "dbg_log.h"
 #include "use_slp.h"
 #include "logindefs.h"
 #include "error_codes.h"
 #include "rpasswd-client.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #if !defined(IPV6_V6ONLY) && defined(__linux__)
 #define IPV6_V6ONLY   26
 #endif
