@@ -32,8 +32,6 @@
 #include <string.h>
 #include <signal.h>
 #include <libgen.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/resource.h>
 #ifdef HAVE_LIBNSCD_H
 #include <libnscd.h>
@@ -43,12 +41,9 @@
 #include "libldap.h"
 #endif
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
-#include "public.h"
+#include "i18n.h"
 #include "group.h"
+#include "public.h"
 #include "logging.h"
 #include "logindefs.h"
 #include "read-files.h"
@@ -1084,17 +1079,24 @@ create_home_directory (const char *home, uid_t uid, gid_t gid,
 		   home, strerror (errno));
 	  retval = E_HOMEDIR;
 	}
-    }
 
-  if (skeldir != NULL && *skeldir != '\0' && access (skeldir, F_OK) == 0)
-    {
-      if (copy_dir_rec (skeldir, home, 0, uid, gid) != 0)
+      if (skeldir != NULL && *skeldir != '\0' && access (skeldir, F_OK) == 0)
 	{
-	  fprintf (stderr, _("%s: Copying of skel directory failed.\n"),
-		   program);
-	  retval = E_HOMEDIR;
+	  if (copy_dir_rec (skeldir, home, 0, uid, gid) != 0)
+	    {
+	      fprintf (stderr, _("%s: Copying of skel directory failed.\n"),
+		       program);
+	      retval = E_HOMEDIR;
+	    }
 	}
     }
+  else if (skeldir != NULL && *skeldir != '\0')
+    {
+      /* Home directory already exits, don't copy skel directory again.  */
+      fprintf (stderr,
+	       _("%s: Warning: home directory already exists, not modifying it.\n"),
+	       program);
+    }
 
   return retval;
 }
