@@ -32,8 +32,6 @@
 #include <string.h>
 #include <signal.h>
 #include <libgen.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/resource.h>
 #ifdef HAVE_LIBNSCD_H
 #include <libnscd.h>
@@ -43,10 +41,7 @@
 #include "libldap.h"
 #endif
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
+#include "i18n.h"
 #include "public.h"
 #include "group.h"
 #include "logging.h"
@@ -80,8 +75,6 @@ disabled\n"), stdout);
   fputs (_("  -G group,...   List of supplementary groups\n"), stdout);
   fputs (_("  -g gid         Name/number of the users primary group\n"),
 	 stdout);
-  fputs (_("  -k skeldir     Specify an alternative skel directory\n"),
-	 stdout);
   fputs (_("  -l login       Change login name.\n"), stdout);
   fputs (_("  -m             Move home directory to the new path\n"), stdout);
   fputs (_("  -o             Allow duplicate (non-unique) UID\n"), stdout);
@@ -1330,8 +1323,6 @@ main (int argc, char **argv)
       pw_data->todo = DO_MODIFY;
       if (new_login)
 	pw_data->new_name = strdup (new_login);
-      if (new_password)
-	pw_data->newpassword = strdup (new_password);
       if (know_uid)
 	{
 	  pw_data->have_new_uid = 1;
@@ -1371,6 +1362,16 @@ main (int argc, char **argv)
 	    }
 	}
 
+      if (new_password)
+	{
+	  pw_data->newpassword = strdup (new_password);
+	  if (pw_data->use_shadow)
+	    {
+	      pw_data->spn.sp_lstchg = time ((time_t *) 0) / SCALE;
+	      pw_data->sp_changed = 1;
+	    }
+	}
+
 #ifdef USE_LDAP
       if (pw_data->service == S_LDAP)
 	{
