@@ -30,19 +30,14 @@
 #include <unistd.h>
 #include <signal.h>
 #include <getopt.h>
-#include <locale.h>
-#include <libintl.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
 
+#include "i18n.h"
 #include "public.h"
 #include "error_codes.h"
 
-#ifndef _
-#define _(String) gettext (String)
-#endif
-
 #ifndef _PATH_PASSWD
 #define _PATH_PASSWD "/etc/passwd"
 #endif
